NodeType

Enum NodeType 

pub enum NodeType {
Show 16 variants Char = 0, HList = 1, VList = 2, Rule = 3, Insertion = 4, Mark = 5, Adjust = 6, Ligature = 7, Discretionary = 8, WhatsIt = 9, Math = 10, Glue = 11, Kern = 12, Penalty = 13, Unset = 14, MathChar = 15,
}
The type of a Node, as returned by \lastnodetype

Variants



Char = 0

A character node, e.g. a or 1.



HList = 1

A horizontal list node, e.g. \hbox{...}.



VList = 2

A vertical list node, e.g. \vbox{...}.



Rule = 3

A rule node, e.g. \hrule.



Insertion = 4

An insertion node as produced by \insert.



Mark = 5

A mark node as produced by \mark.



Adjust = 6

An adjust node as produced by \vadjust.



Ligature = 7

A ligature node as produced by the ligaturing algorithm.



Discretionary = 8

A discretionary node as produced by the discretionary algorithm.



WhatsIt = 9

A whatsit node, e.g. \special.



Math = 10

A math node.



Glue = 11

A glue node, e.g. \hskip.



Kern = 12

A kern node, e.g. \kern.



Penalty = 13

A penalty node as produced by \penalty.



Unset = 14

An unset node, e.g. \unskip.



MathChar = 15

A math character node, e.g. a or 1 in math mode.

Implementations

Source

impl NodeType

pub fn to_u8(&self) -> u8

Returns the numeric value of the node type, as returned by \lastnodetype.