pub struct BoxTarget<ET: EngineTypes>(/* private fields */);Expand description
Once a box is closed, something is supposed to happen to it; most commonly, it is just added to the parent
node list; but occasionally, something else should happen to it - e.g. \setbox5\hbox{...} implies that
after the node list of the box is closed, it should be put into the box register with index 5 instead.
This struct abstracts over that by carrying a continuation function to be called when the box is closed.
TODO: rethink this in light of ListTarget.
Implementations
Sourceimpl<ET: EngineTypes> BoxTarget<ET>
impl<ET: EngineTypes> BoxTarget<ET>
Sourcepub fn new<F: FnOnce(&mut EngineReferences<'_, ET>, TeXBox<ET>) -> TeXResult<(), ET> + 'static>(
f: F,
) -> Self
pub fn new<F: FnOnce(&mut EngineReferences<'_, ET>, TeXBox<ET>) -> TeXResult<(), ET> + 'static>( f: F, ) -> Self
Create a new box target from the given continuation function.