pub struct Leaders<ET: EngineTypes> {
pub tp: LeaderType,
pub body: LeaderBody<ET>,
pub skip: LeaderSkip<ET>,
}Expand description
A \leaders node, as produced by \leaders, \cleaders or \xleaders.
Fields
tp: LeaderType\leaders, \cleaders or \xleaders.
body: LeaderBody<ET>The node to be repeated for the given skip length; a box or a rule.
skip: LeaderSkip<ET>The skip length along which the body should be repeated.