pub struct ListTarget<ET: EngineTypes, N>(/* private fields */);Expand description
Once a node list is closed, something is supposed to happen to it; most commonly, it is a box-list;
but occasionally, something else should happen to it - e.g. \vadjust{...} adds the list’s contents
as a vertical adjustment, a^{...} adds it to the superscript-field of the a.character etc.
This struct abstracts over that by carrying a continuation function to be called when the list is closed.
TODO: rethink this in light of BoxTarget.
Implementations
Sourceimpl<ET: EngineTypes, N> ListTarget<ET, N>
impl<ET: EngineTypes, N> ListTarget<ET, N>
Sourcepub fn new<F: FnOnce(&mut EngineReferences<'_, ET>, Vec<N>, SourceRef<ET>) -> TeXResult<(), ET> + 'static>(
f: F,
) -> Self
pub fn new<F: FnOnce(&mut EngineReferences<'_, ET>, Vec<N>, SourceRef<ET>) -> TeXResult<(), ET> + 'static>( f: F, ) -> Self
Create a new list target from the given continuation function.